Dense layers
------------

.. automodule:: lasagne.layers.dense

.. currentmodule:: lasagne.layers

.. autoclass:: DenseLayer
   :members:

.. autoclass:: NonlinearityLayer
   :members:

.. autoclass:: NINLayer
    :members:

